==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/sv-SE/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekräfta storlekar för borttagning av bulk',
    'bulk_restore'      => 'Bekräfta massåterställning av tillgångar', 
  'bulk_delete_help'	=> 'Granska tillgångarna för delad borttagning nedan. En gång raderas kan dessa tillgångar återställas, men de kommer inte längre att vara associerade med några användare de tilldelas för närvarande.',
  'bulk_restore_help'	=> 'Granska tillgångar för massåterställning nedan. När återställd, kommer dessa tillgångar inte att associeras med några användare som de tidigare tilldelats.',
  'bulk_delete_warn'	=> 'Du håller på att ta bort: asset_count-tillgångar.',
  'bulk_restore_warn'	=> 'Du håller på att återställa :asset_count tillgångar.',
    'bulk_update'		=> 'Bulk Update Assets',
    'bulk_update_help'	=> 'I det här formuläret kan du uppdatera flera tillgångar på en gång. Fyll bara i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
    'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna för en enda tillgång.|Du håller på att redigera egenskaperna för :asset_count tillgångar.',
    'bulk_update_with_custom_field' => 'Notera att tillgångarna är :asset_model_count olika typer av modeller.',
    'bulk_update_model_prefix' => 'På modeller', 
    'bulk_update_custom_field_unique' => 'Detta är ett unikt fält och kan inte bulk redigeras.',
    'checkedout_to'		=> 'Utcheckad till',
    'checkout_date'		=> 'Utcheckningsdatum',
    'checkin_date'		=> 'Incheckningsdatum',
    'checkout_to'		=> 'Checka ut till',
    'cost'				=> 'Inköpskostnad',
    'create'			=> 'Skapa Tillgång',
    'date'				=> 'Köpdatum',
    'depreciation'	    => 'Avskrivning',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Standard plats',
    'default_location_phone' => 'Telefonnummer för standardplats',
    'eol_date'			=> 'EOL Datum',
    'eol_rate'			=> 'EOL-hastighet',
    'expected_checkin'  => 'Förväntad incheckningsdatum',
    'expires'			=> 'Förfaller',
    'fully_depreciated'	=> 'Helt avskrivna',
    'help_checkout'		=> 'Om du vill tilldela denna tillgång omedelbart, välj "Redo att distribuera" från statuslistan ovan. ',
    'mac_address'		=> 'MAC-adress',
    'manufacturer'		=> 'Tillverkare',
    'model'				=> 'Modell',
    'months'			=> 'månader',
    'name'				=> 'Asset Name',
    'notes'				=> 'Anteckningar',
    'order'				=> 'Order Nummer',
    'qr'				=> 'QR-kod',
    'requestable'		=> 'Användare kan begära denna tillgång',
    'select_statustype'	=> 'Välj Statustyp',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Asset Update',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantin löper ut',
    'years'				=> 'år',
    'asset_location' => 'Uppdatera tillgångsplats',
    'asset_location_update_default_current' => 'Uppdatera standardplats och aktuell plats',
    'asset_location_update_default' => 'Uppdatera endast standardplats',
    'asset_location_update_actual' => 'Uppdatera endast faktisk plats',
    'asset_not_deployable' => 'Denna tillgångs status kan inte distribueras. Denna tillgång kan inte checkas ut.',
    'asset_deployable' => 'Denna status är distribuerbar. Denna tillgång kan checkas ut.',
    'processing_spinner' => 'Bearbetar... (Detta kan ta lite tid på stora filer)',
    'optional_infos'  => 'Valfri information',
    'order_details'   => 'Beställningsrelaterad information'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/sv-SE/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekräfta storlekar för borttagning av bulk',
    'bulk_restore'      => 'Bekräfta massåterställning av tillgångar', 
  'bulk_delete_help'	=> 'Granska tillgångarna för delad borttagning nedan. En gång raderas kan dessa tillgångar återställas, men de kommer inte längre att vara associerade med några användare de tilldelas för närvarande.',
  'bulk_restore_help'	=> 'Granska tillgångar för massåterställning nedan. När återställd, kommer dessa tillgångar inte att associeras med några användare som de tidigare tilldelats.',
  'bulk_delete_warn'	=> 'Du håller på att ta bort: asset_count-tillgångar.',
  'bulk_restore_warn'	=> 'Du håller på att återställa :asset_count tillgångar.',
    'bulk_update'		=> 'Bulk Update Assets',
    'bulk_update_help'	=> 'I det här formuläret kan du uppdatera flera tillgångar på en gång. Fyll bara i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
    'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna för en enda tillgång.|Du håller på att redigera egenskaperna för :asset_count tillgångar.',
    'bulk_update_with_custom_field' => 'Notera att tillgångarna är :asset_model_count olika typer av modeller.',
    'bulk_update_model_prefix' => 'På modeller', 
    'bulk_update_custom_field_unique' => 'Detta är ett unikt fält och kan inte bulk redigeras.',
    'checkedout_to'		=> 'Utcheckad till',
    'checkout_date'		=> 'Utcheckningsdatum',
    'checkin_date'		=> 'Incheckningsdatum',
    'checkout_to'		=> 'Checka ut till',
    'cost'				=> 'Inköpskostnad',
    'create'			=> 'Skapa Tillgång',
    'date'				=> 'Köpdatum',
    'depreciation'	    => 'Avskrivning',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Standard plats',
    'default_location_phone' => 'Telefonnummer för standardplats',
    'eol_date'			=> 'EOL Datum',
    'eol_rate'			=> 'EOL-hastighet',
    'expected_checkin'  => 'Förväntad incheckningsdatum',
    'expires'			=> 'Förfaller',
    'fully_depreciated'	=> 'Helt avskrivna',
    'help_checkout'		=> 'Om du vill tilldela denna tillgång omedelbart, välj "Redo att distribuera" från statuslistan ovan. ',
    'mac_address'		=> 'MAC-adress',
    'manufacturer'		=> 'Tillverkare',
    'model'				=> 'Modell',
    'months'			=> 'månader',
    'name'				=> 'Asset Name',
    'notes'				=> 'Anteckningar',
    'order'				=> 'Order Nummer',
    'qr'				=> 'QR-kod',
    'requestable'		=> 'Användare kan begära denna tillgång',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Välj Statustyp',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Asset Update',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantin löper ut',
    'years'				=> 'år',
    'asset_location' => 'Uppdatera tillgångsplats',
    'asset_location_update_default_current' => 'Uppdatera standardplats och aktuell plats',
    'asset_location_update_default' => 'Uppdatera endast standardplats',
    'asset_location_update_actual' => 'Uppdatera endast faktisk plats',
    'asset_not_deployable' => 'Denna tillgångs status kan inte distribueras. Denna tillgång kan inte checkas ut.',
    'asset_deployable' => 'Denna status är distribuerbar. Denna tillgång kan checkas ut.',
    'processing_spinner' => 'Bearbetar... (Detta kan ta lite tid på stora filer)',
    'optional_infos'  => 'Valfri information',
    'order_details'   => 'Beställningsrelaterad information'
];
